## v0.5.0 (2026-02-11)

### Feat

- multi-stage jobs support, strict acceptance validation, and claim-by-job
- claim worker (#8)

## v0.4.0 (2026-02-09)

### Feat

- add poster wallet bind command
- add verifier lane flag and task type listing (#6)
- add job accept/reject commands

## v0.3.0 (2026-02-09)

### Feat

- **job.py**: add job preview by id to allow results preview before unlock

## v0.2.0 (2026-02-08)

### Feat

- create top level auth onboarding command; deprecate init (#2)
- x402 golden path

## v0.1.0 (2026-02-08)
